"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildStepLines = exports.buildExpressionLine = exports.buildValue = exports.buildSelector = exports.buildPageLine = exports.didPageChange = void 0;
const util_1 = require("util");
exports.didPageChange = (step, previous) => {
    if (!previous)
        return false;
    return step.event.page !== previous.event.page;
};
exports.buildPageLine = (step) => {
    return `page = await qawolf.waitForPage(page.context(), ${step.event.page});`;
};
exports.buildSelector = (step) => {
    const { selector } = step.event;
    if (!selector.includes(`"`))
        return `"${selector}"`;
    if (!selector.includes(`'`))
        return `'${selector}'`;
    return '`' + selector.replace(/`/g, '\\`') + '`';
};
exports.buildValue = ({ action, value }) => {
    if (action === 'scroll') {
        const scrollValue = value;
        return `{ x: ${scrollValue.x}, y: ${scrollValue.y} }`;
    }
    if (util_1.isUndefined(value))
        return '';
    return JSON.stringify(value);
};
exports.buildExpressionLine = (step) => {
    const { action } = step;
    const args = [exports.buildSelector(step)];
    const value = exports.buildValue(step);
    if (value)
        args.push(value);
    let methodOpen = `page.${action}(`;
    if (action === 'scroll') {
        methodOpen = `qawolf.scroll(page, `;
    }
    const expression = `await ${methodOpen}${args.join(', ')});`;
    return expression;
};
exports.buildStepLines = (step, previous) => {
    const lines = [];
    if (exports.didPageChange(step, previous)) {
        lines.push(exports.buildPageLine(step));
    }
    lines.push(exports.buildExpressionLine(step));
    return lines;
};
//# sourceMappingURL=buildStepLines.js.map