"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildClickSteps = void 0;
const tslib_1 = require("tslib");
const debug_1 = tslib_1.__importDefault(require("debug"));
const debug = debug_1.default('qawolf:buildClickSteps');
const filterClickEvents = (events) => {
    return events.filter((event, i) => {
        event.index = i;
        if (!event.isTrusted)
            return false;
        if (!['click', 'mousedown'].includes(event.name))
            return false;
        const previousEvent = events[i - 1];
        if (previousEvent &&
            ['keydown', 'keyup'].includes(previousEvent.name) &&
            event.time - previousEvent.time < 50) {
            debug(`skip click shortly after previous event ${event.time}`);
            return false;
        }
        let name = event.target.name;
        if (name)
            name = name.toLowerCase();
        return name !== 'select';
    });
};
const groupClickEvents = (events, timeWindow = 200) => {
    const groupedEvents = [];
    let group = [];
    events.forEach((event) => {
        if (!group.length) {
            group.push(event);
            return;
        }
        const lastEvent = group[group.length - 1];
        if (event.time - lastEvent.time < timeWindow) {
            group.push(event);
            return;
        }
        groupedEvents.push(group);
        group = [event];
    });
    if (group.length) {
        groupedEvents.push(group);
    }
    return groupedEvents;
};
exports.buildClickSteps = (events) => {
    const clickEvents = filterClickEvents(events);
    const groupedClickEvents = groupClickEvents(clickEvents);
    const steps = [];
    groupedClickEvents.forEach((events) => {
        let event = events[0];
        const inputEvent = events.find((event) => {
            const name = event.target.name || '';
            return name.toLowerCase() === 'input';
        });
        if (inputEvent) {
            event = inputEvent;
        }
        steps.push({
            action: 'click',
            index: steps.length,
            event: event,
        });
    });
    return steps;
};
//# sourceMappingURL=buildClickSteps.js.map