"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildKeySteps = exports.KeyStepFactory = void 0;
const tslib_1 = require("tslib");
const debug_1 = tslib_1.__importDefault(require("debug"));
const event_1 = require("./event");
const removeShortcutKeyEvents_1 = require("./removeShortcutKeyEvents");
const debug = debug_1.default('qawolf:buildKeySteps');
const MODIFIER_KEYS = ['Alt', 'Control', 'Meta', 'Shift'];
const isSpecialKey = (key) => key.length > 1;
const isModifierKey = (key) => MODIFIER_KEYS.some(modifier => key.includes(modifier));
class KeyStepFactory {
    constructor(events) {
        this._pendingKeydownEvents = [];
        this._selectAllTarget = null;
        this._steps = [];
        this._events = events;
    }
    _buildStep(_a) {
        var { event } = _a, options = tslib_1.__rest(_a, ["event"]);
        let action = options.action || 'type';
        if (!options.action &&
            this._selectAllTarget &&
            JSON.stringify(this._selectAllTarget) === JSON.stringify(event.target)) {
            this._selectAllTarget = null;
            action = 'fill';
        }
        const step = {
            action,
            event,
            index: this._steps.length,
            value: options.value,
        };
        debug('build step %j', step);
        this._steps.push(step);
    }
    _buildPendingKeydowns() {
        const events = this._pendingKeydownEvents;
        if (!events.length)
            return;
        const value = events.map(e => e.value).join('');
        debug(`build pending keydowns ${events.length}: ${value}`);
        this._buildStep({ event: events[0], value });
        this._pendingKeydownEvents = [];
    }
    _didPageChange(event) {
        if (!this._pendingKeydownEvents.length)
            return false;
        return event.page !== this._pendingKeydownEvents[0].page;
    }
    _handleKeyDown(event) {
        if (isModifierKey(event.value || '')) {
            debug(`skip modifier ${event.value}`);
            return;
        }
        if (isSpecialKey(event.value)) {
            this._buildPendingKeydowns();
            debug(`build press ${event.value}`);
            this._buildStep({ action: 'press', event, value: event.value });
        }
        else {
            this._pendingKeydownEvents.push(event);
        }
    }
    buildSteps() {
        const filteredEvents = removeShortcutKeyEvents_1.removeShortcutKeyEvents('selectall', removeShortcutKeyEvents_1.removeShortcutKeyEvents('paste', this._events));
        filteredEvents.forEach(event => {
            if (!event.isTrusted)
                return;
            if (this._didPageChange(event))
                this._buildPendingKeydowns();
            if (event.name === 'keydown') {
                this._handleKeyDown(event);
                return;
            }
            if (!event_1.isKeyEvent(event))
                this._buildPendingKeydowns();
            if (event_1.isPasteEvent(event)) {
                this._buildStep({ event, value: event.value });
            }
            else if (event_1.isSelectAllEvent(event)) {
                this._selectAllTarget = event.target;
            }
        });
        this._buildPendingKeydowns();
        return this._steps;
    }
}
exports.KeyStepFactory = KeyStepFactory;
exports.buildKeySteps = (events) => {
    const factory = new KeyStepFactory(events);
    return factory.buildSteps();
};
//# sourceMappingURL=buildKeySteps.js.map