"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeShortcutKeyEvents = exports.findShortcutKeyEvents = void 0;
const tslib_1 = require("tslib");
const debug_1 = tslib_1.__importDefault(require("debug"));
const lodash_1 = require("lodash");
const debug = debug_1.default('qawolf:removeShortcutKeyEvents');
const isControlEvent = (event) => {
    return event.value.startsWith('Meta') || event.value.startsWith('Control');
};
exports.findShortcutKeyEvents = (key, events, triggerIndex) => {
    const downCmd = lodash_1.findLast(events, (event, eventIndex) => eventIndex < triggerIndex &&
        event.name === 'keydown' &&
        isControlEvent(event));
    const downCharacter = lodash_1.findLast(events, (event, eventIndex) => eventIndex < triggerIndex &&
        event.name === 'keydown' &&
        event.value == key);
    const upCmd = lodash_1.find(events, (event, eventIndex) => eventIndex > triggerIndex &&
        event.name === 'keyup' &&
        isControlEvent(event));
    const upCharacter = lodash_1.find(events, (event, eventIndex) => eventIndex > triggerIndex &&
        event.name === 'keyup' &&
        event.value == key);
    if (!downCmd || !downCharacter) {
        debug(`Could not find matching shortcut ${key}`);
        return [];
    }
    return [downCmd, downCharacter, upCharacter, upCmd].filter(e => e);
};
exports.removeShortcutKeyEvents = (eventName, events) => {
    const filteredEvents = events.slice(0);
    let key;
    if (eventName === 'paste') {
        key = 'v';
    }
    else if (eventName === 'selectall') {
        key = 'a';
    }
    else {
        throw new Error(`Shortcut ${eventName} not supported`);
    }
    filteredEvents.forEach((event, triggerIndex) => {
        if (event.name !== eventName)
            return;
        const pasteKeyEvents = exports.findShortcutKeyEvents(key, filteredEvents, triggerIndex);
        lodash_1.remove(filteredEvents, e => pasteKeyEvents.includes(e));
    });
    return filteredEvents;
};
//# sourceMappingURL=removeShortcutKeyEvents.js.map