"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CodeFileUpdater = void 0;
const tslib_1 = require("tslib");
const debug_1 = tslib_1.__importDefault(require("debug"));
const fs_extra_1 = require("fs-extra");
const CodeUpdater_1 = require("./CodeUpdater");
const debug = debug_1.default('qawolf:CodeFileUpdater');
const loadCodeFile = (path) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const codeExists = yield fs_extra_1.pathExists(path);
    if (!codeExists)
        throw new Error(`No code found at ${path}`);
    return fs_extra_1.readFile(path, 'utf8');
});
class CodeFileUpdater extends CodeUpdater_1.CodeUpdater {
    constructor(path) {
        super();
        this._path = path;
    }
    static create(path) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            debug(`load code from ${path}`);
            const initialCode = yield loadCodeFile(path);
            const updater = new CodeFileUpdater(path);
            yield updater._prepare();
            updater._initialCode = initialCode;
            return updater;
        });
    }
    _loadCode() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return loadCodeFile(this._path);
        });
    }
    _updateCode(code) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            yield fs_extra_1.outputFile(this._path, code, 'utf8');
        });
    }
    discard() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            this._locked = true;
            if (process.env.QAW_CREATE === 'true') {
                debug('discard code');
                yield fs_extra_1.remove(this._path);
            }
            else {
                debug('revert to initial code');
                yield this._updateCode(this._initialCode);
            }
        });
    }
    path() {
        return this._path;
    }
}
exports.CodeFileUpdater = CodeFileUpdater;
//# sourceMappingURL=CodeFileUpdater.js.map