"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CodeReconciler = void 0;
const tslib_1 = require("tslib");
const debug_1 = tslib_1.__importDefault(require("debug"));
const VirtualCode_1 = require("../build-code/VirtualCode");
const patchCode_1 = require("./patchCode");
const debug = debug_1.default('qawolf:CodeReconciler');
class CodeReconciler {
    constructor() {
        this._virtualCode = new VirtualCode_1.VirtualCode([]);
    }
    _insertNewLines({ actualCode, virtualCode, }) {
        const newLines = this._virtualCode.newLines(virtualCode);
        if (newLines.length < 1)
            return actualCode;
        const patch = newLines.map(line => `${line}\n`).join('') + patchCode_1.PATCH_HANDLE;
        debug(`insert new lines: ${patch}`);
        return patchCode_1.patchCode({ code: actualCode, patch });
    }
    _updateLastLine({ actualCode, virtualCode, }) {
        const linePatch = this._virtualCode.buildPatch(virtualCode);
        if (!linePatch)
            return actualCode;
        const indexToReplace = actualCode.lastIndexOf(linePatch.original);
        if (indexToReplace < 0) {
            debug('skip last line update: cannot find original code to update "%j"', linePatch.original);
            return actualCode;
        }
        debug('update last line');
        const updatedCode = actualCode.slice(0, indexToReplace) +
            actualCode
                .slice(indexToReplace)
                .replace(linePatch.original, linePatch.updated);
        return updatedCode;
    }
    hasChanges(virtualCode) {
        const hasPatch = !!this._virtualCode.buildPatch(virtualCode);
        if (hasPatch) {
            debug('has patch for last line');
            return true;
        }
        const hasNewLines = this._virtualCode.newLines(virtualCode).length > 0;
        if (hasNewLines) {
            debug('has new lines');
            return true;
        }
        debug('no changes');
        return false;
    }
    reconcile({ actualCode, virtualCode }) {
        let updatedCode = this._updateLastLine({ actualCode, virtualCode });
        updatedCode = this._insertNewLines({
            actualCode: updatedCode,
            virtualCode,
        });
        return updatedCode;
    }
    update(virtualCode) {
        if (this._virtualCode.lines().length > virtualCode.lines().length) {
            debug('skip virtual code update with less expressions');
            return;
        }
        this._virtualCode = virtualCode;
    }
}
exports.CodeReconciler = CodeReconciler;
//# sourceMappingURL=CodeReconciler.js.map