"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CodeUpdater = void 0;
const tslib_1 = require("tslib");
const debug_1 = tslib_1.__importDefault(require("debug"));
const events_1 = require("events");
const buildVirtualCode_1 = require("../build-code/buildVirtualCode");
const CodeReconciler_1 = require("./CodeReconciler");
const format_1 = require("./format");
const patchCode_1 = require("./patchCode");
const debug = debug_1.default('qawolf:CodeUpdater');
class CodeUpdater extends events_1.EventEmitter {
    constructor() {
        super();
        this._locked = false;
        this._reconciler = new CodeReconciler_1.CodeReconciler();
    }
    _update(code) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            debug('update code');
            this.emit('codeupdate', code);
            yield this._updateCode(code);
        });
    }
    _prepare() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const code = yield this._loadCode();
            const patchLine = format_1.getLineIncludes(code, patchCode_1.PATCH_HANDLE);
            if (!patchLine) {
                throw new Error(`Could not find "${patchCode_1.PATCH_HANDLE}"`);
            }
        });
    }
    finalize() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            this._locked = true;
            let code = yield this._loadCode();
            code = format_1.removeLinesIncluding(code, patchCode_1.PATCH_HANDLE);
            yield this._update(code);
        });
    }
    update(options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (this._locked) {
                debug(`skip update: update in progress`);
                return;
            }
            const updatedVirtualCode = buildVirtualCode_1.buildVirtualCode(options.steps);
            if (!this._reconciler.hasChanges(updatedVirtualCode)) {
                debug(`skip update: no virtual changes`);
                return;
            }
            this._locked = true;
            const actualCode = yield this._loadCode();
            const updatedCode = this._reconciler.reconcile({
                actualCode,
                virtualCode: updatedVirtualCode,
            });
            yield this._update(updatedCode);
            this._reconciler.update(updatedVirtualCode);
            this._locked = false;
        });
    }
}
exports.CodeUpdater = CodeUpdater;
//# sourceMappingURL=CodeUpdater.js.map