"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContextEventCollector = void 0;
const tslib_1 = require("tslib");
const debug_1 = tslib_1.__importDefault(require("debug"));
const events_1 = require("events");
const config_1 = require("../config");
const utils_1 = require("../utils");
const addScript_1 = require("../web/addScript");
const debug = debug_1.default('qawolf:ContextEventCollector');
class ContextEventCollector extends events_1.EventEmitter {
    constructor(context) {
        super();
        this._attribute = config_1.loadConfig().attribute;
        utils_1.forEachPage(context, (page) => this._collectPageEvents(page));
    }
    static create(context) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            yield addScript_1.addScriptToContext(context);
            yield utils_1.indexPages(context);
            return new ContextEventCollector(context);
        });
    }
    _collectPageEvents(page) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (page.isClosed())
                return;
            const index = page.createdIndex;
            debug(`collect page events ${index} ${this._attribute}`);
            yield page.exposeFunction('cp_collectEvent', (event) => {
                debug(`emit %j`, event);
                this.emit('elementevent', event);
            });
            yield utils_1.initEvaluateScript(page, ({ attribute, pageIndex }) => {
                const web = window.qawolf;
                new web.PageEventCollector({
                    attribute,
                    pageIndex,
                    sendEvent: window.cp_collectEvent,
                });
            }, {
                attribute: this._attribute,
                pageIndex: index,
            });
        });
    }
}
exports.ContextEventCollector = ContextEventCollector;
//# sourceMappingURL=ContextEventCollector.js.map