"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CreateManager = void 0;
const tslib_1 = require("tslib");
const debug_1 = tslib_1.__importDefault(require("debug"));
const buildSteps_1 = require("../build-workflow/buildSteps");
const CodeFileUpdater_1 = require("./CodeFileUpdater");
const ContextEventCollector_1 = require("./ContextEventCollector");
const createPrompt_1 = require("./createPrompt");
const debug = debug_1.default('qawolf:CreateManager');
class CreateManager {
    constructor(options) {
        this._events = [];
        this._codeUpdater = options.codeUpdater;
        this._collector = options.collector;
        this._collector.on('elementevent', (event) => this.update(event));
    }
    static create(options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            debug(`create code at ${options.codePath}`);
            const codeUpdater = yield CodeFileUpdater_1.CodeFileUpdater.create(options.codePath);
            const collector = yield ContextEventCollector_1.ContextEventCollector.create(options.context);
            const manager = new CreateManager({
                codeUpdater,
                collector,
            });
            return manager;
        });
    }
    update(event) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            this._events.push(event);
            const steps = buildSteps_1.buildSteps(this._events);
            yield this._codeUpdater.update({ steps });
        });
    }
    finalize() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const shouldSave = yield createPrompt_1.createPrompt(this._codeUpdater.path());
            if (shouldSave) {
                yield this._codeUpdater.finalize();
            }
            else {
                yield this._codeUpdater.discard();
            }
        });
    }
}
exports.CreateManager = CreateManager;
//# sourceMappingURL=CreateManager.js.map