"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const plugin_commonjs_1 = tslib_1.__importDefault(require("@rollup/plugin-commonjs"));
const plugin_json_1 = tslib_1.__importDefault(require("@rollup/plugin-json"));
const plugin_node_resolve_1 = tslib_1.__importDefault(require("@rollup/plugin-node-resolve"));
const plugin_virtual_1 = tslib_1.__importDefault(require("@rollup/plugin-virtual"));
const rollup_plugin_typescript_1 = tslib_1.__importDefault(require("rollup-plugin-typescript"));
const selectorEvaluatorSource = tslib_1.__importStar(require("playwright-core/lib/generated/selectorEvaluatorSource"));
const playwrightEvaluator = `
const evaluator = new (${selectorEvaluatorSource.source})([]);
export const querySelectorAll = (...args) => evaluator.querySelectorAll(...args);
`;
exports.default = {
    input: './src/web/index.ts',
    output: {
        file: './build/qawolf.web.js',
        format: 'iife',
        name: 'qawolf',
        sourcemap: true,
        strict: false,
    },
    onwarn: (warning, next) => {
        if (warning.code === 'EVAL')
            return;
        if (warning.code === 'THIS_IS_UNDEFINED')
            return;
        next(warning);
    },
    plugins: [
        plugin_virtual_1.default({
            './playwrightEvaluator': playwrightEvaluator,
        }),
        plugin_commonjs_1.default(),
        plugin_node_resolve_1.default({ browser: true }),
        rollup_plugin_typescript_1.default({ declaration: false }),
        plugin_json_1.default(),
    ],
};
//# sourceMappingURL=rollup.js.map