"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findTestPath = void 0;
const tslib_1 = require("tslib");
const fs_extra_1 = require("fs-extra");
const glob_1 = tslib_1.__importDefault(require("glob"));
const path_1 = tslib_1.__importDefault(require("path"));
const isFile = (path) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const stat = yield fs_extra_1.lstat(path);
    return stat.isFile();
});
exports.findTestPath = ({ name, rootDir, }) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    if (path_1.default.isAbsolute(name) && (yield isFile(name)))
        return name;
    let ext = '';
    if (!path_1.default.extname(name))
        ext = '{ts,js}';
    const files = yield new Promise((resolve, reject) => {
        glob_1.default(`**/*${name}*${ext}`, { absolute: true, cwd: rootDir }, (error, files) => {
            if (error)
                reject(error);
            else
                resolve(files);
        });
    });
    if (files.length < 1) {
        throw new Error(`No files match "${name}"`);
    }
    if (files.length > 1) {
        throw new Error(`Multiple files match "${name}"`);
    }
    const testPath = files[0];
    if (!(yield isFile(testPath))) {
        throw new Error(`No tests match "${name}"`);
    }
    return testPath;
});
//# sourceMappingURL=findTestPath.js.map