export declare type Action = 'click' | 'fill' | 'press' | 'scroll' | 'selectOption' | 'type';
export declare type BrowserName = 'chromium' | 'firefox' | 'webkit';
export declare type Callback<S = void, T = void> = (data?: S) => T;
export interface Doc {
    attrs?: any;
    children?: Doc[];
    content?: string;
    name?: string;
    type: string;
    voidElement?: boolean;
}
export interface ElementEvent {
    isTrusted: boolean;
    name: ElementEventName;
    page: number;
    selector: string;
    target: Doc;
    time: number;
}
export declare type ElementEventName = 'click' | 'input' | 'keydown' | 'keyup' | 'mousedown' | 'paste' | 'scroll' | 'selectall';
export interface InputEvent extends ElementEvent {
    name: 'input';
    value: string | null;
}
export interface KeyEvent extends ElementEvent {
    name: 'keydown' | 'keyup';
    value: string;
}
export interface PasteEvent extends ElementEvent {
    name: 'paste';
    value: string;
}
export interface ScrollEvent extends ElementEvent {
    name: 'scroll';
    value: ScrollValue;
}
export declare type ScrollValue = {
    x: number;
    y: number;
};
export interface Step {
    action: Action;
    event: ElementEvent;
    index: number;
    value?: StepValue;
}
export declare type StepValue = string | ScrollValue | null | undefined;
export interface Workflow {
    device?: string;
    name: string;
    steps: Step[];
    url: string;
}
