"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.stopVideos = exports.saveArtifacts = void 0;
const tslib_1 = require("tslib");
const debug_1 = tslib_1.__importDefault(require("debug"));
const path_1 = require("path");
const playwright_video_1 = require("playwright-video");
const forEachPage_1 = require("./forEachPage");
const saveConsoleLogs_1 = require("../page/saveConsoleLogs");
const debug = debug_1.default('qawolf:saveArtifacts');
const capturesToStop = [];
exports.saveArtifacts = (context, saveDir) => {
    const includeVideo = !!playwright_video_1.getFfmpegPath();
    let pageCount = 0;
    return forEachPage_1.forEachPage(context, (page) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const timestamp = Date.now();
        const pageIndex = pageCount++;
        debug(`save artifacts for page ${pageIndex} at ${timestamp}`);
        try {
            yield saveConsoleLogs_1.saveConsoleLogs(page, path_1.join(saveDir, `logs_${pageIndex}_${timestamp}.txt`));
            if (includeVideo) {
                debug(`save video for page ${pageIndex}`);
                const capture = yield playwright_video_1.saveVideo(page, path_1.join(saveDir, `video_${pageIndex}_${timestamp}.mp4`));
                capturesToStop.push(capture);
            }
            else {
                debug(`ffmpeg not found, skipping video for page ${pageIndex}`);
            }
        }
        catch (error) {
            debug(`cannot save artifacts for page ${pageIndex}: ${error.message}`);
        }
    }));
};
exports.stopVideos = () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    yield Promise.all(capturesToStop.map((capture) => capture.stop()));
});
//# sourceMappingURL=saveArtifacts.js.map