"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.launch = exports.getLaunchOptions = exports.getBrowserType = exports.parseBrowserName = void 0;
const tslib_1 = require("tslib");
const debug_1 = tslib_1.__importDefault(require("debug"));
const os_1 = require("os");
const util_1 = require("util");
const Registry_1 = require("./Registry");
const debug = debug_1.default('qawolf:launch');
const parseBool = (value) => {
    const lowerCaseValue = (value || '').toLowerCase();
    return ['1', 't', 'true'].includes(lowerCaseValue);
};
exports.parseBrowserName = (name) => {
    if (name === 'firefox' || name === 'webkit')
        return name;
    return 'chromium';
};
exports.getBrowserType = (browserName) => {
    let playwright;
    try {
        playwright = require('playwright');
    }
    catch (error) {
        try {
            playwright = require(`playwright-${browserName}`);
        }
        catch (error) {
            throw new Error('qawolf requires playwright to be installed');
        }
    }
    return playwright[browserName];
};
exports.getLaunchOptions = (options = {}) => {
    const launchOptions = Object.assign({}, options);
    const headlessEnv = process.env.QAW_HEADLESS;
    if (util_1.isNullOrUndefined(options.headless) && !util_1.isNullOrUndefined(headlessEnv)) {
        launchOptions.headless = parseBool(headlessEnv);
    }
    const browserName = exports.parseBrowserName(options.browserName || process.env.QAW_BROWSER);
    const defaultArgs = [];
    if (browserName === 'chromium' && os_1.platform() === 'linux') {
        defaultArgs.push('--no-sandbox');
    }
    return Object.assign(Object.assign({ args: defaultArgs }, launchOptions), { browserName });
};
exports.launch = (options = {}) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const launchOptions = exports.getLaunchOptions(options);
    debug('launch %j', launchOptions);
    const browser = yield exports.getBrowserType(launchOptions.browserName).launch(launchOptions);
    Registry_1.Registry.instance().setBrowser(browser);
    return browser;
});
//# sourceMappingURL=launch.js.map