"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.scroll = exports.getScrollValue = void 0;
const tslib_1 = require("tslib");
const DEFAULT_TIMEOUT = 30000;
exports.getScrollValue = (page, elementHandle) => {
    return page.evaluate((element) => {
        return { x: element.scrollLeft, y: element.scrollTop };
    }, elementHandle);
};
exports.scroll = (page, selector, { timeout, x, y }) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const elementHandle = yield page.waitForSelector(selector);
    const startScrollValue = yield exports.getScrollValue(page, elementHandle);
    try {
        yield page.waitForFunction(({ element, x, y }) => {
            element.scroll(x, y);
            return element.scrollLeft === x && element.scrollTop === y;
        }, { element: elementHandle, x, y }, { polling: 100, timeout: timeout || DEFAULT_TIMEOUT });
    }
    catch (error) {
        const endScrollValue = yield exports.getScrollValue(page, elementHandle);
        if (startScrollValue.x !== endScrollValue.x ||
            startScrollValue.y !== endScrollValue.y) {
            return;
        }
        throw new Error(`could not scroll element ${selector}`);
    }
});
//# sourceMappingURL=scroll.js.map