"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.waitFor = void 0;
const tslib_1 = require("tslib");
exports.waitFor = (predicate, options = {}) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const value = yield predicate();
    if (value)
        return value;
    const timeout = isNaN(options.timeout) ? 30000 : options.timeout;
    const interval = isNaN(options.interval) ? 100 : options.interval;
    return new Promise((resolve, reject) => {
        let intervalId, timeoutId;
        let isDone = false;
        const done = (value) => {
            if (isDone)
                return;
            isDone = true;
            clearInterval(intervalId);
            clearTimeout(timeoutId);
            if (value)
                resolve(value);
            else
                reject(`waitFor timed out after ${timeout}ms`);
        };
        intervalId = setInterval(() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            const value = yield predicate();
            if (value)
                done(value);
        }), interval);
        timeoutId = setTimeout(() => done(), timeout);
    });
});
//# sourceMappingURL=waitFor.js.map