"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getClickableAncestor = exports.isClickable = exports.isVisible = void 0;
const serialize_1 = require("./serialize");
exports.isVisible = (element, computedStyle) => {
    const htmlElement = element;
    if (htmlElement.offsetWidth <= 0 || htmlElement.offsetHeight <= 0) {
        return false;
    }
    if (computedStyle && computedStyle.visibility === 'hidden') {
        return false;
    }
    if (computedStyle && computedStyle.display === 'none') {
        return false;
    }
    return true;
};
exports.isClickable = (element, computedStyle) => {
    const clickable = computedStyle.cursor === 'pointer';
    return clickable && exports.isVisible(element, computedStyle);
};
exports.getClickableAncestor = (element) => {
    let ancestor = element;
    console.debug('qawolf: get clickable ancestor for', serialize_1.getXpath(element));
    while (ancestor.parentElement) {
        if (['a', 'button', 'input'].includes(ancestor.tagName.toLowerCase())) {
            console.debug(`qawolf: found clickable ancestor: ${ancestor.tagName}`, serialize_1.getXpath(ancestor));
            return ancestor;
        }
        if (!exports.isClickable(ancestor.parentElement, window.getComputedStyle(ancestor.parentElement))) {
            console.debug('qawolf: found clickable ancestor', serialize_1.getXpath(ancestor));
            return ancestor;
        }
        ancestor = ancestor.parentElement;
    }
    console.debug('qawolf: found clickable ancestor', serialize_1.getXpath(ancestor));
    return ancestor;
};
//# sourceMappingURL=element.js.map