"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.interceptConsoleLogs = exports.patchConsole = exports.formatArgument = void 0;
const serialize_1 = require("./serialize");
const LOG_LEVELS = ['debug', 'error', 'info', 'log', 'warn'];
exports.formatArgument = (argument) => {
    if (typeof argument === 'string') {
        return argument;
    }
    if (argument && argument.nodeName) {
        return serialize_1.getXpath(argument);
    }
    try {
        return JSON.stringify(argument);
    }
    catch (error) {
        if (argument && argument.toString) {
            return argument.toString();
        }
        return '';
    }
};
exports.patchConsole = () => {
    if (window.pwutilsPatchedConsole)
        return;
    window.pwutilsPatchedConsole = true;
    LOG_LEVELS.forEach((level) => {
        const browserLog = console[level].bind(console);
        console[level] = (...args) => {
            const message = args
                .map((arg) => exports.formatArgument(arg))
                .join(' ');
            browserLog(...args);
            if (message.includes('__playwright'))
                return;
            const callbacks = window.pwutilsLogCallbacks || [];
            callbacks.forEach((callback) => {
                callback(level, message);
            });
        };
    });
};
exports.interceptConsoleLogs = (callbackName) => {
    exports.patchConsole();
    const callbacks = window.pwutilsLogCallbacks || [];
    callbacks.push(window[callbackName]);
    window.pwutilsLogCallbacks = callbacks;
};
//# sourceMappingURL=interceptConsoleLogs.js.map