"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isDynamic = exports.getWords = void 0;
const tslib_1 = require("tslib");
const index_json_1 = tslib_1.__importDefault(require("an-array-of-english-words/index.json"));
const layoutWords = ['col', 'fa', 'grid'];
const allowedWords = new Set([
    'btn',
    'div',
    'dropdown',
    'html',
    'img',
    'inputtext',
    'lg',
    'li',
    'login',
    'logout',
    'mui',
    'nav',
    'signin',
    'signout',
    'signup',
    'sm',
    'svg',
    'textinput',
    'todo',
    'ul',
    ...layoutWords,
    ...index_json_1.default,
]);
const SCORE_THRESHOLD = 0.5;
exports.getWords = (value) => {
    const classWords = [];
    value.split(/[ \-_]+|(?=[A-Z])/).forEach((word) => {
        if (!word)
            return;
        classWords.push(word.toLowerCase());
    });
    return classWords;
};
exports.isDynamic = (value, threshold = SCORE_THRESHOLD) => {
    if (!value)
        return true;
    const classWords = exports.getWords(value);
    const digits = (value.match(/\d+/g) || []).join('').length;
    if (digits > 1 && !layoutWords.find((word) => classWords.includes(word))) {
        return true;
    }
    const includedWords = classWords.filter((word) => allowedWords.has(word));
    if (classWords.length - includedWords.length >= 2)
        return true;
    return includedWords.length / classWords.length <= threshold;
};
//# sourceMappingURL=isDynamic.js.map