"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.iterateCues = exports.CueTypesRanked = void 0;
exports.CueTypesRanked = [
    'attribute',
    'text',
    'id',
    'aria-label',
    'title',
    'name',
    'for',
    'contenteditable',
    'value',
    'placeholder',
    'alt',
    'src',
    'href',
    'class',
    'tag',
];
const include = (cues, ...include) => cues.filter((cue) => include.includes(cue.type));
const sortByRank = (cues) => cues.sort((a, b) => {
    const aType = exports.CueTypesRanked.indexOf(a.type);
    const bType = exports.CueTypesRanked.indexOf(b.type);
    if (aType < bType)
        return -1;
    if (aType > bType)
        return 1;
    if (a.level < b.level)
        return -1;
    if (a.level > b.level)
        return 1;
    return 0;
});
function* iterateGroups(targetCues, ancestorCue) {
    if (ancestorCue) {
        yield* targetCues.map((targetCue) => [ancestorCue, targetCue]);
    }
    else {
        yield* targetCues.map((cue) => [cue]);
    }
}
function* iterateType(targetCues, ancestorCues, type) {
    const typeTargetCues = include(targetCues, type);
    yield* iterateGroups(typeTargetCues);
    const eligibleTypes = exports.CueTypesRanked.slice(1, exports.CueTypesRanked.indexOf(type) + 1);
    for (const ancestorCue of include(ancestorCues, ...eligibleTypes)) {
        if (ancestorCue.type === type) {
            yield* iterateGroups(include(targetCues, ...eligibleTypes), ancestorCue);
        }
        else {
            yield* iterateGroups(typeTargetCues, ancestorCue);
        }
    }
}
function* iterateCues(cues) {
    const ancestorCues = sortByRank(cues.filter((cue) => cue.level !== 0));
    const targetCues = sortByRank(cues.filter((cue) => cue.level === 0));
    yield* iterateGroups(include(targetCues, 'attribute'));
    for (const ancestorCue of include(ancestorCues, 'attribute')) {
        yield* iterateGroups(targetCues, ancestorCue);
    }
    for (const type of exports.CueTypesRanked.slice(1)) {
        yield* iterateType(targetCues, ancestorCues, type);
    }
}
exports.iterateCues = iterateCues;
//# sourceMappingURL=iterateCues.js.map