"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildSelector = exports.toSelector = exports.isMatch = void 0;
const iterateCues_1 = require("./iterateCues");
const cues_1 = require("./cues");
const playwrightEvaluator_1 = require("./playwrightEvaluator");
const serialize_1 = require("./serialize");
exports.isMatch = ({ selectorParts, target }) => {
    const result = playwrightEvaluator_1.querySelectorAll({ parts: selectorParts }, document.body);
    if (result[0] !== target && !target.contains(result[0])) {
        return false;
    }
    return true;
};
exports.toSelector = (selectorParts) => {
    const names = selectorParts.map((s) => s.name);
    if (!names.includes('text')) {
        return selectorParts.map((s) => s.body).join(' ');
    }
    return selectorParts.map(({ body, name }) => `${name}=${body}`).join(' >> ');
};
exports.buildSelector = (options) => {
    const tagName = options.target.tagName.toLowerCase();
    if (['body', 'html'].includes(tagName)) {
        return tagName;
    }
    const cues = cues_1.buildCues(options);
    for (const cueGroup of iterateCues_1.iterateCues(cues)) {
        const selectorParts = cues_1.buildSelectorParts(cueGroup);
        if (exports.isMatch({ selectorParts, target: options.target })) {
            const selector = exports.toSelector(selectorParts);
            return selector;
        }
    }
    return `xpath=${serialize_1.getXpath(options.target)}`;
};
//# sourceMappingURL=selector.js.map