"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.nodeToDoc = exports.nodeToHtml = exports.htmlToDoc = exports.getXpath = void 0;
const html_parse_stringify_1 = require("@jperl/html-parse-stringify");
const buildXpath = (node) => {
    if (!node || node.nodeType !== 1)
        return '';
    const element = node;
    if (element.id) {
        const quote = element.id.includes(`'`) ? `"` : `'`;
        return `//*[@id=${quote}${element.id}${quote}]`;
    }
    const children = element.parentNode ? element.parentNode.children : [];
    const sames = [].filter.call(children, (x) => {
        return x.tagName === element.tagName;
    });
    const result = buildXpath(element.parentNode) +
        '/' +
        element.tagName.toLowerCase() +
        (sames.length > 1
            ? '[' + ([].indexOf.call(sames, element) + 1) + ']'
            : '');
    return result;
};
exports.getXpath = (node) => {
    const result = buildXpath(node);
    return result
        .replace('svg', "*[name()='svg']")
        .replace('path', "*[name()='path']");
};
exports.htmlToDoc = (html) => {
    const result = html_parse_stringify_1.parse(html);
    if (result.length !== 1) {
        console.debug('qawolf: invalid html', html, result);
        throw new Error('htmlToDoc: only supports individual nodes');
    }
    return result[0];
};
exports.nodeToHtml = (node) => {
    const serializer = new XMLSerializer();
    const serialized = serializer
        .serializeToString(node)
        .replace(/ xmlns="(.*?)"/g, '')
        .replace(/(\r\n|\n|\r)/gm, '');
    return serialized;
};
exports.nodeToDoc = (node) => {
    const html = exports.nodeToHtml(node);
    return exports.htmlToDoc(html);
};
//# sourceMappingURL=serialize.js.map